{% raw %}
    {% ckan_extends %}

    {% block styles %}
        {{ super() }}
        {% asset "{% endraw %}{{ project_shortname }}/{{ project_shortname }}{% raw %}-css" %}
    {% endblock %}

    {% block scripts %}
        {{ super() }}
        {% asset "{% endraw %}{{ project_shortname }}/{{ project_shortname }}{% raw %}-js" %}
    {% endblock %}
{% endraw %}
